@@ -1,5 +1,5 @@
-from .loader import encrypt_file, gen_key
 import click
+from . import loader
 
 @click.group()
 def cmd():
@@ -10,18 +10,18 @@ def cmd():
 @click.argument('key')
 @click.argument('fp')
 def encrypt(key, fp):
-    print(f"{fp} with key {key}")
-    encrypt_file(fp, key)
+    loader.encrypt_file(fp, key)
     click.echo('encrypted!')
 
 
 @cmd.command()
-def genkey():
-    gen_key()
+@click.argument('expire')
+def genkey(expire):
+    loader.gen_key(int(expire))
 
 
 cli = click.CommandCollection(sources=[cmd,])
 
 
 def main():
-    cli()
\ No newline at end of file
+    cli()
